##  Bulk Updating Data Through an Excel File
SAP LeanIX’s import feature allows you to efficiently add, update, and remove data in fact sheets through an Excel file. Here’s a high-level guide to bulk updating your data:
  1. Use the export option to create a template file for import. This file includes columns for each necessary fact sheet attribute in the proper format. You can choose which columns to include or exclude by switching to table view and selecting and unhiding the attributes to be shown before exporting.
  2. In the exported template, each row corresponds to a fact sheet, and each column corresponds to a fact sheet attribute. Fill or update the data in the spreadsheet as required.
  3. Import the completed Excel file back into SAP LeanIX through the import option. Based on the changes made in the spreadsheet, this process will add, update, or remove data in your fact sheets.


For a detailed guide, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio89254838ad684a9492c2e7ac083a5b7e_LowRes.png)
Bulk Updating Data Through Export and Import Feature
**Tip**
SAP LeanIX offers several features to help maintain and improve the quality and completeness of your data. These include fact sheet completeness, mandatory fields, quality seals, surveys, reference catalog, discoveries, and integrations. Learn more about them in [Increasing Your Data Quality](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality?locale=en-US&state=PRODUCTION&version=CLOUD "Enhance data quality in SAP LeanIX with features like fact sheet completion scores, fact sheet subscriptions, mandatory fields, quality seals, and surveys. Use integrations and discovery tools for accurate, up-to-date data.").
When updating SaaS applications, IT components, and SAP applications, leverage the reference catalog and discovery features. The reference catalog intelligently recommends suitable items for fact sheets, and once linked, important attributes like the product category, SSO, hosting details, lifecycles, version specifics, and more are automatically updated. This enhances data quality and accelerates data entry. To learn more, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.") and [Discoveries and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.").
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
